Config class

Annotations
  • @JsonSerializable.new(createToJson: false)

Constructors

Config({List<FileReplacememnt>? fileReplacement, List<StringReplacement>? stringReplacement, List<FolderReplacement>? folderReplacement})
Config.fromJson(Map<String, dynamic> json)
factory
Config.fromPath(String path)
factory

Properties

fileReplacement List<FileReplacememnt>?
final
folderReplacement List<FolderReplacement>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringReplacement List<StringReplacement>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited